# Bleeding/Ischaemia Risk Estimate Verification

The purpose of the bleeding and ischaemia models is to assess the trade-off between bleeding and ischaemia risk.

## Separate Verification of Each Model



## Verification of the Trade-off